@@ -14,6 +14,7 @@ pub struct WsMessage(pub String);
 pub struct Subscribe {
     pub addr: Addr<crate::handlers::web_sockets::WebSocketConnection>,
     pub subject: String,
+    pub agent: String,
 }
 
 /// A message containing a Resource, which should be sent to subscribers
@@ -22,6 +23,6 @@ pub struct Subscribe {
 pub struct CommitMessage {
     /// Target subject of the commit
     pub subject: String,
-    /// Full resource of the Commit itself
-    pub resource: atomic_lib::Resource,
+    /// Full resource of the Commit itself, the new resource, and the old one
+    pub commit_response: atomic_lib::commit::CommitResponse,
 }
