@@ -1,11 +1,14 @@
 //! App state, which is accessible from handlers
-use crate::{commit_monitor::CommitMonitor, config::Config, errors::BetterResult};
+use crate::{
+    commit_monitor::CommitMonitor, config::Config, errors::AtomicServerResult, search::SearchState,
+};
 use atomic_lib::{
     agents::{generate_public_key, Agent},
     Storelike,
 };
 
-/// Context for the server (not an individual request).
+/// Data object available to handlers and actors.
+/// Contains the store, configuration and addresses for Actix Actors.
 // This struct is cloned accross all threads, so make sure the fields are thread safe.
 // A good option here is to use Actors for things that can change (e.g. commit_monitor)
 #[derive(Clone)]
@@ -16,54 +19,76 @@ pub struct AppState {
     pub config: Config,
     /// The Actix Address of the CommitMonitor, which should receive updates when a commit is applied
     pub commit_monitor: actix::Addr<CommitMonitor>,
+    pub search_state: SearchState,
 }
 
 /// Creates the server context.
-/// Initializes a store on disk.
+/// Initializes or opens a store on disk.
+/// Initializes logging.
 /// Creates a new agent, if neccessary.
-pub fn init(config: Config) -> BetterResult<AppState> {
-    // Enable all logging
-    std::env::set_var("RUST_LOG", "info");
+pub fn init(config: Config) -> AtomicServerResult<AppState> {
+    // Enable logging, but hide most tantivy logs
+    std::env::set_var("RUST_LOG", "info,tantivy=warn");
     env_logger::init();
+    const VERSION: &str = env!("CARGO_PKG_VERSION");
+    log::info!("Atomic-server {}. Use --help for more options. Visit https://docs.atomicdata.dev and https://github.com/joepio/atomic-data-rust.", VERSION);
+
     // Check if atomic-server is already running somwehere, and try to stop it. It's not a problem if things go wrong here, so errors are simply logged.
     let _ = crate::process::terminate_existing_processes(&config)
         .map_err(|e| log::error!("Could not check for running instance: {}", e));
 
-    const VERSION: &str = env!("CARGO_PKG_VERSION");
-    log::info!("Atomic-server {}. Use --help for more options. Visit https://docs.atomicdata.dev and https://github.com/joepio/atomic-data-rust.", VERSION);
-
+    log::info!("Opening database...");
     let store = atomic_lib::Db::init(&config.store_path, config.local_base_url.clone())?;
     if config.initialize {
         log::info!("Initialize: creating and populating new Database...");
         atomic_lib::populate::populate_default_store(&store)
             .map_err(|e| format!("Failed to populate default store. {}", e))?;
         // Building the index here is needed to perform TPF queries on imported resources
+        log::info!(
+            "Building index... (this could take a few minutes for larger existing databases)"
+        );
         store.build_index(true)?;
+        log::info!("Building index finished!");
     }
+    log::info!("Setting default agent...");
     set_default_agent(&config, &store)?;
     if config.initialize {
-        atomic_lib::populate::populate_hierarchy(&store)
+        log::info!("Running populate commands...");
+        atomic_lib::populate::create_drive(&store)
             .map_err(|e| format!("Failed to populate hierarchy. {}", e))?;
+        atomic_lib::populate::set_drive_rights(&store, true)
+            .map_err(|e| format!("Failed to set drive rights. {}", e))?;
         atomic_lib::populate::populate_collections(&store)
             .map_err(|e| format!("Failed to populate collections. {}", e))?;
         atomic_lib::populate::populate_endpoints(&store)
             .map_err(|e| format!("Failed to populate endpoints. {}", e))?;
         set_up_initial_invite(&store)?;
         // This means that editing the .env does _not_ grant you the rights to edit the Drive.
-        set_up_drive(&store)?;
+        log::info!("Setting rights to Drive {}", store.get_base_url());
     }
 
-    use actix::Actor;
+    // Initialize search constructs
+    log::info!("Starting search service...");
+    let search_state = SearchState::new(&config)?;
+
+    // Initialize commit monitor, which watches commits and sends these to the commit_monitor actor
+    log::info!("Starting commit monitor...");
+    let commit_monitor = crate::commit_monitor::create_commit_monitor(
+        store.clone(),
+        search_state.clone(),
+        config.clone(),
+    );
 
     Ok(AppState {
         store,
         config,
-        commit_monitor: crate::commit_monitor::CommitMonitor::default().start(),
+        commit_monitor,
+        search_state,
     })
 }
 
 /// Create a new agent if it does not yet exist.
-fn set_default_agent(config: &Config, store: &impl Storelike) -> BetterResult<()> {
+fn set_default_agent(config: &Config, store: &impl Storelike) -> AtomicServerResult<()> {
     let ag_cfg: atomic_lib::config::Config = match atomic_lib::config::read_config(
         &config.config_file_path,
     ) {
@@ -92,7 +117,7 @@ fn set_default_agent(config: &Config, store: &impl Storelike) -> BetterResult<()
                 }
             }
         }
-        Err(_) => {
+        Err(_no_config) => {
             let agent = store.create_agent(Some("root"))?;
             let cfg = atomic_lib::config::Config {
                 agent: agent.subject.clone(),
@@ -115,13 +140,13 @@ fn set_default_agent(config: &Config, store: &impl Storelike) -> BetterResult<()
         created_at: 0,
         name: None,
     };
-    log::info!("Setting default Agent {}", &agent.subject);
+    log::info!("Default Agent is set: {}", &agent.subject);
     store.set_default_agent(agent);
     Ok(())
 }
 
 /// Creates the first Invitation that is opened by the user on the Home page.
-fn set_up_initial_invite(store: &impl Storelike) -> BetterResult<()> {
+fn set_up_initial_invite(store: &impl Storelike) -> AtomicServerResult<()> {
     let subject = format!("{}/setup", store.get_base_url());
     log::info!("Creating initial Invite at {}", subject);
     let mut invite = atomic_lib::Resource::new_instance(atomic_lib::urls::INVITE, store)?;
@@ -160,17 +185,3 @@ fn set_up_initial_invite(store: &impl Storelike) -> BetterResult<()> {
     invite.save_locally(store)?;
     Ok(())
 }
-
-/// Get the Drive resource (base URL), set agent as the Root user, provide write access
-fn set_up_drive(store: &impl Storelike) -> BetterResult<()> {
-    log::info!("Setting rights to Drive {}", store.get_base_url());
-    // Now let's add the agent as the Root user and provide write access
-    let mut drive = store.get_resource(store.get_base_url())?;
-    let agents = vec![store.get_default_agent()?.subject];
-    // TODO: add read rights to public, maybe
-    drive.set_propval(atomic_lib::urls::WRITE.into(), agents.clone().into(), store)?;
-    drive.set_propval(atomic_lib::urls::READ.into(), agents.into(), store)?;
-    drive.set_propval_string(atomic_lib::urls::DESCRIPTION.into(), &format!("Welcome to your Atomic-Server! Register your User by visiting [`/setup`]({}/setup). After that, edit this page by pressing `edit` in the navigation bar menu.", store.get_base_url()), store)?;
-    drive.save_locally(store)?;
-    Ok(())
-}
