@@ -1,6 +1,6 @@
 //! Parse CLI options, setup on boot, read .env values
 
-use crate::errors::BetterResult;
+use crate::errors::AtomicServerResult;
 use clap::Parser;
 use dotenv::dotenv;
 use std::env;
@@ -15,10 +15,10 @@ pub struct Opts {
     #[clap(subcommand)]
     pub command: Option<Command>,
     /// Recreates the `/setup` Invite for creating a new Root User. Also re-runs various populate commands, and re-builds the index
-    #[clap(long)]
+    #[clap(long, env = "ATOMIC_INITIALIZE")]
     pub initialize: bool,
     /// Re-creates the value index. Parses all the resources. Do this if your collections have issues.
-    #[clap(long)]
+    #[clap(long, env = "ATOMIC_REBUILD_INDEX")]
     pub rebuild_index: bool,
     /// Use staging environments for services like LetsEncrypt
     #[clap(long, env = "ATOMIC_DEVELOPMENT")]
@@ -29,17 +29,18 @@ pub struct Opts {
     /// The contact mail address for Let's Encrypt HTTPS setup
     #[clap(long, env = "ATOMIC_EMAIL")]
     pub email: Option<String>,
-    /// The port where the HTTP app is available
-    #[clap(short, long, default_value = "80", env = "ATOMIC_PORT")]
+    // 9.883 is decimal for the `⚛` character.
+    /// The port where the HTTP app is available. Set to 80 if you want this to be available on the network.
+    #[clap(short, long, default_value = "9883", env = "ATOMIC_PORT")]
     pub port: u32,
-    /// The port where the HTTPS app is available
-    #[clap(long, default_value = "443", env = "ATOMIC_PORT")]
+    /// The port where the HTTPS app is available. Sert to 443 if you want this to be available on the network.
+    #[clap(long, default_value = "9884", env = "ATOMIC_PORT_HTTPS")]
     pub port_https: u32,
-    /// The IP address of the server
+    /// The IP address of the server. Set to 0.0.0.0 if you want this to be available to other devices on your network.
     #[clap(long, default_value = "0.0.0.0", env = "ATOMIC_IP")]
     pub ip: IpAddr,
-    /// If we're using HTTPS or plaintext HTTP.
-    /// Is disabled when using cert_init
+    /// Use HTTPS instead of HTTP.
+    /// Will get certificates from LetsEncrypt.
     #[clap(long, env = "ATOMIC_HTTPS")]
     pub https: bool,
     /// Endpoint where the front-end assets are hosted
@@ -55,6 +56,15 @@ pub struct Opts {
     /// Path for atomic data config directory. Defaults to "~/.config/atomic/""
     #[clap(long, env = "ATOMIC_CONFIG_DIR")]
     pub config_dir: Option<PathBuf>,
+    /// CAUTION: Makes data public on the `/search` endpoint. When enabled, it allows POSTing to the /search endpoint and returns search results as single triples, without performing authentication checks. See https://github.com/joepio/atomic-data-rust/blob/master/server/rdf-search.md
+    #[clap(long, env = "ATOMIC_RDF_SEARCH")]
+    pub rdf_search: bool,
+    /// By default, Atomic-Server keeps previous verions of resources indexed in Search. When enabling this flag, previous versions of resources are removed from the search index when their values are updated.
+    #[clap(long, env = "ATOMIC_REMOVE_PREVIOUS_SEARCH")]
+    pub remove_previous_search: bool,
+    /// CAUTION: Skip authentication checks, making all data public. Improves performance.
+    #[clap(long, env = "ATOMIC_PUBLIC_MODE")]
+    pub public_mode: bool,
 }
 
 #[derive(Parser, Clone, Debug)]
@@ -114,12 +124,14 @@ pub struct Config {
     pub static_path: PathBuf,
     /// Path to where the store is located. (defaults to `~/.config/atomic/db`)
     pub store_path: PathBuf,
-    /// init app
+    /// Path to where the search index for tantivy full text search is located  (defaults to `~/.config/atomic/search_index`)
+    pub search_index_path: PathBuf,
+    /// If true, the initialization scripts will be ran (create first Drive, Agent, indexing, etc)
     pub initialize: bool,
 }
 
 /// Creates the server config, reads .env values and sets defaults
-pub fn init() -> BetterResult<Config> {
+pub fn init() -> AtomicServerResult<Config> {
     // Parse .env file (do this before parsing the CLI opts)
     dotenv().ok();
 
@@ -131,11 +143,13 @@ pub fn init() -> BetterResult<Config> {
     } else {
         atomic_lib::config::default_config_dir_path()?
     };
-    let mut config_file_path = atomic_lib::config::default_config_file_path()?;
+    let mut config_file_path = config_dir.join("config.toml");
     let mut store_path = config_dir.clone();
     store_path.push("db");
     let mut https_path = config_dir.clone();
     https_path.push("https");
+    let mut search_index_path = config_dir.clone();
+    search_index_path.push("search_index");
     let mut cert_path = config_dir.clone();
     cert_path.push("https/cert.pem");
     let mut key_path = config_dir.clone();
@@ -196,5 +210,6 @@ pub fn init() -> BetterResult<Config> {
         local_base_url,
         static_path,
         store_path,
+        search_index_path,
     })
 }
