@@ -1,8 +1,6 @@
 use crate::{
-    appstate::AppState,
-    content_types::get_accept,
-    content_types::ContentType,
-    errors::{AppError, BetterResult},
+    appstate::AppState, content_types::get_accept, content_types::ContentType,
+    errors::AtomicServerResult, helpers::get_client_agent,
 };
 use actix_web::{web, HttpResponse};
 use atomic_lib::Storelike;
@@ -11,16 +9,17 @@ use std::sync::Mutex;
 /// Respond to a single resource.
 /// The URL should match the Subject of the resource.
 pub async fn get_resource(
-    subject_end: Option<web::Path<String>>,
+    path: Option<web::Path<String>>,
     data: web::Data<Mutex<AppState>>,
     req: actix_web::HttpRequest,
-) -> BetterResult<HttpResponse> {
-    let context = data.lock().unwrap();
+) -> AtomicServerResult<HttpResponse> {
+    let appstate = data.lock().unwrap();
 
-    let mut content_type = get_accept(req.headers());
-    let base_url = &context.config.local_base_url;
+    let headers = req.headers();
+    let mut content_type = get_accept(headers);
+    let base_url = &appstate.config.local_base_url;
     // Get the subject from the path, or return the home URL
-    let subject = if let Some(subj_end) = subject_end {
+    let subject = if let Some(subj_end) = path {
         let mut subj_end_string = subj_end.as_str();
         if content_type == ContentType::Html {
             if let Some((ext, path)) = try_extension(subj_end_string) {
@@ -40,7 +39,10 @@ pub async fn get_resource(
     } else {
         String::from(base_url)
     };
-    let store = &context.store;
+
+    let store = &appstate.store;
+
+    let for_agent = get_client_agent(headers, &appstate, subject.clone())?;
     let mut builder = HttpResponse::Ok();
     log::info!("get_resource: {} as {}", subject, content_type.to_mime());
     builder.header("Content-Type", content_type.to_mime());
@@ -50,10 +52,7 @@ pub async fn get_resource(
         "Cache-Control",
         "no-store, no-cache, must-revalidate, private",
     );
-    let resource = store
-        .get_resource_extended(&subject, false)
-        // TODO: Don't always return 404 - only when it's actually not found!
-        .map_err(|e| AppError::other_error(e.to_string()))?;
+    let resource = store.get_resource_extended(&subject, false, for_agent.as_deref())?;
     match content_type {
         ContentType::Json => {
             let body = resource.to_json(store)?;
