@@ -1,5 +1,5 @@
 use crate::{appstate::AppState, content_types::get_accept};
-use crate::{content_types::ContentType, errors::BetterResult, helpers::empty_to_nothing};
+use crate::{content_types::ContentType, errors::AtomicServerResult, helpers::empty_to_nothing};
 use actix_web::{web, HttpResponse};
 use atomic_lib::Storelike;
 use serde::Deserialize;
@@ -19,9 +19,13 @@ pub async fn tpf(
     data: web::Data<Mutex<AppState>>,
     req: actix_web::HttpRequest,
     query: web::Query<TpfQuery>,
-) -> BetterResult<HttpResponse> {
-    let mut context = data.lock().unwrap();
-    let store = &mut context.store;
+) -> AtomicServerResult<HttpResponse> {
+    let appstate = data.lock().unwrap();
+    let store = &appstate.store;
+
+    if !appstate.config.opts.public_mode {
+        return Err("/tpf endpoint is only available on public mode".into());
+    }
     // This is how locally items are stored (which don't know their full subject URL) in Atomic Data
     let mut builder = HttpResponse::Ok();
     let content_type = get_accept(req.headers());
