@@ -1,9 +1,9 @@
 //! Checks if the process is running, kills a runnig process if it is.
 
-use crate::{config::Config, errors::BetterResult};
+use crate::{config::Config, errors::AtomicServerResult};
 
 /// Checks if the server is running. If it is, kill that process. Also creates creates a new PID.
-pub fn terminate_existing_processes(config: &Config) -> BetterResult<()> {
+pub fn terminate_existing_processes(config: &Config) -> AtomicServerResult<()> {
     let pid_maybe = match std::fs::read_to_string(pid_path(config)) {
         Ok(content) => str::parse::<i32>(&content).ok(),
         Err(_e) => None,
@@ -12,7 +12,9 @@ pub fn terminate_existing_processes(config: &Config) -> BetterResult<()> {
         use sysinfo::{ProcessExt, SystemExt};
         let mut s = sysinfo::System::new_all();
         let retry_secs = 1;
-        let mut tries_left = 15;
+        let mut tries_left = 30;
+        // either friendly (Terminate) or not friendly (Kill)
+        let mut signal = sysinfo::Signal::Term;
         if let Some(process) = s.process(pid) {
             log::warn!(
                 "Terminating existing running instance of atomic-server (process ID: {})...",
@@ -32,8 +34,14 @@ pub fn terminate_existing_processes(config: &Config) -> BetterResult<()> {
                         );
                         std::thread::sleep(std::time::Duration::from_secs(retry_secs));
                     } else {
-                        log::error!("Could not terminate other atomic-server, exiting...");
-                        std::process::exit(1);
+                        if signal == sysinfo::Signal::Kill {
+                            log::error!("Could not terminate other atomic-server, exiting...");
+                            std::process::exit(1);
+                        }
+                        log::warn!("Terminate signal did not work, let's try again with Kill...",);
+                        _process.kill(sysinfo::Signal::Kill);
+                        tries_left = 15;
+                        signal = sysinfo::Signal::Kill;
                     }
                     continue;
                 };
@@ -46,7 +54,7 @@ pub fn terminate_existing_processes(config: &Config) -> BetterResult<()> {
 }
 
 /// Removes the process id file in the config directory meant for signaling this instance is running.
-pub fn remove_pid(config: &Config) -> BetterResult<()> {
+pub fn remove_pid(config: &Config) -> AtomicServerResult<()> {
     if std::fs::remove_file(pid_path(config)).is_err() {
         log::warn!(
             "Could not remove process file at {}",
@@ -63,7 +71,7 @@ fn pid_path(config: &Config) -> std::path::PathBuf {
 }
 
 /// Writes a `pid` file in the config directory to signal which instance is running.
-fn create_pid(config: &Config) -> BetterResult<()> {
+fn create_pid(config: &Config) -> AtomicServerResult<()> {
     use std::io::Write;
     let pid = sysinfo::get_current_pid()
         .map_err(|_| "Failed to get process info required to create process ID")?;
