@@ -1,10 +1,12 @@
 use actix_cors::Cors;
 use actix_web::{middleware, web, HttpServer};
-use atomic_lib::{errors::AtomicResult, Storelike};
+use atomic_lib::Storelike;
 use std::sync::Mutex;
 
+use crate::errors::AtomicServerResult;
+
 /// Start the server
-pub async fn serve(config: crate::config::Config) -> AtomicResult<()> {
+pub async fn serve(config: &crate::config::Config) -> AtomicServerResult<()> {
     // Setup the database and more
     let appstate = crate::appstate::init(config.clone())?;
 
@@ -16,17 +18,27 @@ pub async fn serve(config: crate::config::Config) -> AtomicResult<()> {
         let appstate_clone = appstate.clone();
 
         actix_web::rt::spawn(async move {
-            log::warn!("Building index... This could take a while, expect worse performance until 'Building index finished'");
+            log::warn!("Building value index... This could take a while, expect worse performance until 'Building value index finished'");
             appstate_clone
                 .store
                 .clear_index()
-                .expect("Failed to clear index");
+                .expect("Failed to clear value index");
             appstate_clone
                 .store
                 .build_index(true)
-                .expect("Failed to build index");
-            log::info!("Building index finished!");
+                .expect("Failed to build value index");
+            log::info!("Building value index finished!");
         });
+        log::info!("Removing existing search index...");
+        appstate_clone
+            .search_state
+            .writer
+            .write()
+            .expect("Could not get a lock on search writer")
+            .delete_all_documents()?;
+        log::info!("Building search index...");
+        crate::search::add_all_resources(&appstate_clone.search_state, &appstate.store)?;
+        log::info!("Search index finished!");
     }
 
     let server = HttpServer::new(move || {
@@ -43,7 +55,7 @@ pub async fn serve(config: crate::config::Config) -> AtomicResult<()> {
             .wrap(cors)
             .wrap(middleware::Logger::default())
             .wrap(middleware::Compress::default())
-            .configure(crate::routes::config_routes)
+            .configure(|app| crate::routes::config_routes(app, &appstate.config))
             .default_service(web::to(|| {
                 log::error!("Wrong route, should not happen with normal requests");
                 actix_web::HttpResponse::NotFound()
@@ -65,9 +77,9 @@ pub async fn serve(config: crate::config::Config) -> AtomicResult<()> {
                 if std::fs::File::open(&config.cert_path).is_err()
                     || crate::https::check_expiration_certs()
                 {
-                    crate::https::cert_init_server(&config).await?;
+                    crate::https::cert_init_server(config).await?;
                 }
-                let https_config = crate::https::get_https_config(&config)
+                let https_config = crate::https::get_https_config(config)
                     .expect("HTTPS TLS Configuration with Let's Encrypt failed.");
                 let endpoint = format!("{}:{}", config.opts.ip, config.opts.port_https);
                 println!("{}", message);
@@ -89,8 +101,7 @@ pub async fn serve(config: crate::config::Config) -> AtomicResult<()> {
             .run()
             .await?;
     }
-    crate::process::remove_pid(&config)?;
-
+    crate::process::remove_pid(config)?;
     Ok(())
 }
 
